package com.yaros.almacen;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.yaros.almacen.model.Product;
import com.yaros.almacen.service.ProductQueryService;
import com.yaros.almacen.service.ProductService;

@Component
public class AlmacenRunApp {
	@Autowired
	private ProductService productService;
	@Autowired
	private ProductQueryService productQueryService;
	@Autowired
	private AlmacenHelp help;
	
	public void run(String[] args) {
		if(args.length < 1) {
			System.out.println("Error de Sintaxis");
			System.out.println(help.getHelp());
		} else if(args.length == 1){
			switch(args[0].toLowerCase()) {
			case "-la":
				System.out.printf("%s\t%-10s\t%-10s\t%s\t%s\t%s\t%s\t%s\n", "ID", "Name", "Manufacturer", "Shelf", "Weight", "Size", "Num", "Notes");
				productService.findAll().forEach(f -> System.out.printf("%s\t%-10s\t%-10s\t%s\t%s\t%s\t%s\t%s\n",
						f.getId(), f.getName(), f.getManufacturer(), f.getShelf(), f.getWeight(), f.getSize(), f.getNum(),
						f.getNotes().stream().collect(Collectors.joining(", "))));
				break;
			case "-lm":
				productService.findAllManufacturers().forEach(System.out::println);
				break;
			case "-ln":
				productService.findAllNotes().forEach(System.out::println);
				break;
			default:
				System.out.println("Error de sintaxis");
				System.out.println(help.getHelp());
			}
		} else if (args.length % 2 != 0) {
			System.out.println("Error de sintaxis");
			System.out.println(help.getHelp());
		} else if (args.length > 8) {
			System.out.println("Error de sintaxis");
			System.out.println(help.getHelp());
		} else {
			List<String[]> argumentos = new ArrayList<>();
			for(int i = 0; i < args.length;  i += 2) {
				argumentos.add(new String[] {args[i], args[i + 1]});
			};
			
			boolean error = false;
			
			for(String[] argumento : argumentos) {
				switch(argumento[0].toLowerCase()) {
				/*case "-gi":
					filmQueryService. (argumento[1].split(","));
					break;*/
				case "-gm":
					productQueryService.anyManufacturer(argumento[1].split(","));
					break;
				case "-gn":
					productQueryService.anyNote(argumento[1]);
					break;
				case "-t":
					productQueryService.nameContains(argumento[1]);
					break;
				default: error = true;
					System.out.println("Error de sintaxis");
					System.out.println(help.getHelp());		
				}	
			}
			if(!error) {
				Collection<Product> result = productQueryService.exec();
				System.out.printf("%s\t%-10s\t%-10s\t%s\t%s\t%s\t%s\t%s\n", "ID", "Name", "Manufacturer", "Shelf", "Weight", "Size", "Num", "Notes");
				if(result != null) {
					result.forEach(f -> System.out.printf("%s\t%-10s\t%-10s\t%s\t%s\t%s\t%s\t%s\n",
							f.getId(), f.getName(), f.getManufacturer(), f.getShelf(), f.getWeight(), f.getSize(), f.getNum(),
							f.getNotes().stream().collect(Collectors.joining(", "))));
				} else  {
					System.out.println("No hay peliculas que cumplan esos critetios. Lo sentimos");
				}
			}
		}
	}
}
